'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _globby = require('globby');

var _globby2 = _interopRequireDefault(_globby);

var _babelFile = require('babel-file');

var _babelFile2 = _interopRequireDefault(_babelFile);

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (babel) {
  var t = babel.types;
  var variableDeclarators = [];

  return {
    name: "s2s-axios-api-manager",
    visitor: {
      VariableDeclarator: function VariableDeclarator(path, state) {
        if (path.node.id.name.endsWith('Request')) {
          variableDeclarators.push(path.node.id.name);
        }
      },

      Program: {
        enter: function enter(path, state) {
          var _state$opts = state.opts,
              input = _state$opts.input,
              output = _state$opts.output;


          if (!input) {
            throw new Error('require input option');
          }

          if (!output) {
            throw new Error('require output option');
          }

          var inputFiles = _globby2.default.sync(input);
          var outputFiles = _globby2.default.sync(output);

          var outputDirPath = output.split("/").reverse().slice(1).reverse().join("/");

          var inputFilesName = inputFiles.map(function (f) {
            return f.split("/").pop();
          });
          var outputFilesName = outputFiles.map(function (f) {
            return f.split("/").pop();
          });

          // If there is no input directory file in the output directory, create a file
          inputFilesName.map(function (f) {
            if (outputFilesName.indexOf(f) == -1) {
              _fs2.default.writeFileSync(outputDirPath + "/" + f, "");
            }
          });
        },
        exit: function exit(path, state) {
          var output = state.opts.output;


          var inputFilePath = state.file.opts.filename;
          var inputFileName = inputFilePath.split("/").pop();

          var outputDirPath = output.split("/").reverse().slice(1).reverse().join("/");
          var outputFilePath = outputDirPath + "/" + inputFileName;

          var outputFile = void 0;
          var actionNameArray = [];
          var objectPropertyArray = [];

          _fs2.default.readFile(outputFilePath, function (err, data) {
            var outputFileSrc = data.toString();
            outputFile = (0, _babelFile2.default)(outputFileSrc, {
              filename: outputFilePath
            });

            outputFile.path.traverse({
              VariableDeclarator: function VariableDeclarator(path) {
                actionNameArray.push(path.node.id.name);
              }
            });

            variableDeclarators.forEach(function (val, index, ar) {
              if (actionNameArray.indexOf(val) == -1) {
                outputFile.path.node.body.push(t.ExpressionStatement(t.Identifier(val)));
                var resultSrc = (0, _babelGenerator2.default)(outputFile.ast).code;
                _fs2.default.writeFile(outputFilePath, resultSrc, function (err) {
                  if (err) {
                    throw err;
                  }
                });
              }
            });

            if (actionNameArray.length > variableDeclarators.length) {
              actionNameArray.forEach(function (val, index, ar) {
                if (variableDeclarators.indexOf(val) == -1) {
                  outputFile.path.traverse({
                    VariableDeclarator: function VariableDeclarator(path) {
                      if (path.node.id.name == val) {
                        path.remove();
                      }
                    }
                  });
                }
              });
              var resultSrc = (0, _babelGenerator2.default)(outputFile.ast).code;
              _fs2.default.writeFile(outputFilePath, resultSrc, function (err) {
                if (err) {
                  throw err;
                }
              });
            }

            actionNameArray = [];
            variableDeclarators = [];
          });
        }
      }
    }
  };
};